@@ -16,15 +16,11 @@
 
 //! Canvas.
 
-use {
-  crate::{
-    errors::*,
-    plane::{Cell, Plane},
-    point::{Point, Points, POINT_ZERO},
-    rect::{Rect, Rectangles},
-  },
-  dmntk_common::Result,
-};
+use crate::errors::*;
+use crate::plane::{Cell, Plane};
+use crate::point::{Point, Points, POINT_ZERO};
+use crate::rect::{Rect, Rectangles};
+use dmntk_common::Result;
 
 /// Number of layers in canvas.
 pub const LAYER_COUNT: usize = 4;
