@@ -190,19 +190,19 @@ pub const EX_10: &str = r#"
   └────────────────────┴─────────────╨──────────────┴──────────────┘
 "#;
 
-fn eq_vectors(actual: &Vec<String>, expected: &[&str]) {
+fn eq_vectors(actual: &[String], expected: &[&str]) {
   assert_eq!(actual.len(), expected.len());
   for (index, value) in actual.iter().enumerate() {
     assert_eq!(value, expected[index]);
   }
 }
 
-fn eq_matrices(actual: &Vec<Vec<String>>, expected: &[&[&str]]) {
+fn eq_matrices(actual: &[Vec<String>], expected: &[&[&str]]) {
   assert_eq!(actual.len(), expected.len());
   for (r, row) in actual.iter().enumerate() {
     assert_eq!(row.len(), expected[r].len());
-    for c in 0..row.len() {
-      assert_eq!(row[c], expected[r][c]);
+    for (c, col) in row.iter().enumerate() {
+      assert_eq!(col, expected[r][c]);
     }
   }
 }
